#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-I22jzS62qQ92bZ7jlVpSBO
key:                  stack-2.9.3.1-I22jzS62qQ92bZ7jlVpSBO
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  cbab2e25b3f982e13b1e454d09b61422
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-I22jzS62qQ92bZ7jlVpSBO
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-Dt9IcEbIPgo3pXUjrBlJbR
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-BaaOJBYZHtd1MproObBlcZ array-0.5.6.0
    async-2.2.6-IB55pRMOICm7lPJ05sVN9d
    attoparsec-0.14.4-9ctfIIumed0I3W5C5GaWiL base-4.18.2.1
    base64-bytestring-1.2.1.0-FfsKFWslEOoAvWp1oz7NnG
    bytestring-0.11.5.3 casa-client-0.0.3-2c1hfapliq9CihZx5Kuhl
    casa-types-0.0.3-B7dltl9BQBn4l8QqKtLw4U
    colour-2.3.7-IqBe6msxEeC9wavnTrqs50
    conduit-1.3.6.1-F67YktQmHRqJ5R9QX7ucHV
    conduit-extra-1.3.8-6O6CtrkaMBHHbx4pVlP0Hf containers-0.6.7
    crypton-1.0.4-1xkEEzzipS99cinEMvqUU
    crypton-conduit-0.2.3-GldtDWTb9db8DJdSINmLD8 deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-1gq06OiTdkG7AFSCXWttYR
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.8-DB3UOaG7qXI5VF3IgGsPLx filepath-1.4.300.1
    fsnotify-0.4.4.0-84r6CaPs3hNBXv9Pv115GX
    generic-deriving-1.14.7-J0TZoWp8KsQFzSmICi7RYK
    hackage-security-0.6.3.2-219TLj4ZEBEFQbz0cbNHMu
    hashable-1.4.7.0-ISMWzeTPqg7GxJZ08wJoa
    hi-file-parser-0.1.8.0-JazMBkcLu0GJ5t9NsxqDPi
    hpack-0.38.0-CECzEBBDosyJRTc8sCLKir hpc-0.6.2.0
    http-client-0.7.19-ChmOISdzz1UJcIMHPfAR81
    http-client-tls-0.3.6.4-ElwH4yzEtEI653MgXxDs1r
    http-conduit-2.3.9.1-JfPSsRJzPbH5Iu7V1rHBTg
    http-download-0.2.1.0-3YEKPy5ZQtIDXG3Ui42cM
    http-types-0.12.4-LSgWFg4mVle7jKIO2vdgXi
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-AsUnSsxn3m4BqjsoB6sQyG mtl-2.3.1
    mustache-2.4.3.1-Fc3Pt3zGbCZABiygzaXjNi
    neat-interpolation-0.5.1.4-Dmb4BJLht6lF3mbdmZ1m7H
    network-uri-2.6.4.2-JJwr3105NpI16YFQY3IIVN
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-ACOZXD1ji7S90GHMXot2xe
    pantry-0.8.3-EshHsF9FoD5JBmTbJo0NWU
    path-0.9.6-DliTy2WqQQpEQ9MVzd7Gxw
    path-io-1.8.2-GUPplYBqDnTBcD4VBrLKdW
    persistent-2.14.5.2-vRswv1IPIB2LskvgVvYe5
    persistent-sqlite-2.13.2.0-6KbxuTi2sPeI7LZo44hE75 pretty-1.1.3.6
    primitive-0.9.1.0-Dm8O45wtcqd5eoiJyOalCK process-1.6.19.0
    project-template-0.2.1.0-AEHs8nLDX3uL32EdAJEXSL
    random-1.2.1.3-IIwS2aSfjMyGbtdCPZwDHA
    retry-0.9.3.1-L1x0p7Ihvuc11HyYz9ohXT
    rio-0.1.24.0-FOy6ZwlWq6MH6dQTDgjnCZ
    rio-prettyprint-0.1.8.0-Ao0bxRTcFlu1Gc1HyxlW9N
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    streaming-commons-0.2.3.1-1KVkES7o2RW7foxH99w6gs
    tar-0.5.1.1-HKH3Kieby9r24sR0gaCZvT template-haskell-2.20.0.0
    temporary-1.3-2scYfc6PuLr90QcileTdw7 text-2.0.2
    text-metrics-0.3.3-GKJCraGdxnuX98mdV3EI8
    th-reify-many-0.1.10-Ld6aVPKfEdjFRGphxX65do time-1.12.2
    tls-2.0.6-IWkAO9AwBiQ73kMgfqcG7r transformers-0.6.1.0
    typed-process-0.2.13.0-GYH8dmgJgO18MaKcsG1FlY
    unicode-transforms-0.4.0.1-4ytSmmE681KHF2vqfGSA47 unix-2.8.4.0
    unix-compat-0.7.4.1-BZMXqomGfYu4rulQDFCFZv
    unliftio-0.2.25.1-2ijZcbxfdeVCmMwCRtThrP
    unordered-containers-0.2.20.1-6k45pUyQa13JRvzUHn0wS1
    vector-0.13.2.0-B5QnucNm6YY8XIvh7YleVY
    yaml-0.11.11.2-KqhXgUc3VA7C1IL3BQ5ruQ
    zip-archive-0.4.3.2-ENhLoLWDQduFhnorc0VaFP
    zlib-0.7.1.0-Q1HBKHfydpLmfZAi5mmFg

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

